==> aprs4r-0.9.9.4.tar.gz: aprs4r-0.9.9.4/src/aprs4r/tests/APRSMessageTest.rb <==
#!/usr/bin/ruby
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'test/unit'

log4r_file = ENV['APRS4R_LOG4R'] || "#{default_path}/log4r.yaml"
print "log4r_file: #{log4r_file}\n"

require 'aprs4r/APRS4RLogger'
APRS4R::APRS4RLogger::load_yaml_file( log4r_file)

require 'aprs4r/APRSMessage'


module APRS4R

  class APRSMessageTest < Test::Unit::TestCase

    def test_latitude2decimal
      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00N"))
      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00S"))
    end

    def test_longitude2decimal
      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00E"))
      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00W"))
    end

    def test_degree2decimal_zero
      position1 = "0000.00N"
      assert_equal( 0.0, APRSMessage.degree2decimal( position1))

      position2 = "0000.00S"
      assert_equal( 0.0, APRSMessage.degree2decimal( position2))

      position3 = "00000.00E"
      assert_equal( 0.0, APRSMessage.degree2decimal( position3))

      position4 = "00000.00W"
      assert_equal( 0.0, APRSMessage.degree2decimal( position4))
    end

    
    def test_degree2decimal_north
      position = "4900.00N"
      assert_in_delta( 49.0, APRSMessage.degree2decimal( position), 0.0001)
      assert_not_equal( -49.0, APRSMessage.degree2decimal( position))
    end

    def test_degree2decimal_south
      position = "4930.00S"
      assert_in_delta( -49.50, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_second1
      position = "4930.50N"
      assert_in_delta( 49.5083, APRSMessage.degree2decimal( position), 0.0001)
    end

    
    def test_degree2decimal_east
      position = "00800.00E"
      assert_in_delta( 8.0, APRSMessage.degree2decimal( position), 0.0001)
      assert_not_equal( -8.0, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_west
      position = "11245.00W"
      assert_in_delta( -112.75, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_second2
      position = "9423.69N"
      assert_in_delta( 94.3948, APRSMessage.degree2decimal( position), 0.0001)
    end


    def test_has_path
      no_path = APRSMessage.new( "FROM", "TO", nil, "")
      empty_path = APRSMessage.new( "FROM", "TO", [], "")

      assert( !no_path.has_path?)
      assert( !empty_path.has_path?)


      simple_path = APRSMessage.new( "FROM", "TO", ["CALL1"], "")
      complex_path = APRSMessage.new( "FROM", "TO", ["CALL1-3*", "WIDE2-1"], "")
      
      assert( simple_path.has_path?)
      assert( complex_path.has_path?)

      return
    end


    def test_is_local
      no_path = APRSMessage.new( "FROM", "TO", nil, "")
      empty_path = APRSMessage.new( "FROM", "TO", [], "")

      assert( no_path.is_local?)
      assert( empty_path.is_local?)

      
      local_path = APRSMessage.new( "FROM", "TO", ["WIDE1-1", "WIDE2-1"], "")
      remote_path = APRSMessage.new( "FROM", "TO", ["ABCDEF*", "WIDE1", "WIDE2-1"], "")

      assert( local_path.is_local?)
      assert( !remote_path.is_local?)

      return
    end

    
    def test_message
      message = APRSMessage.new( "FROM", "TO", [], ":ABCDEFGHI:Message")
      no_message = APRSMessage.new( "FROM", "TO", [], ">Statustext")

      assert( message.is_message?)
      assert( !no_message.is_message?)

      assert_equal( message.message_recipient, "ABCDEFGHI")
    end


    def test_object
      message = APRSMessage.new( "FROM", "TO", [], ";FFF.FFF+x*111111z1234.56N/01234.56WrAAAAAAAAAABBBBBBBBBB88888888")
      
      assert( message.is_object?)
      assert_equal( "FFF.FFF+x", message.object_address)
      
      assert( message.has_symbol?)
      assert_equal( message.symbol_table, "/")
      assert_equal( message.symbol_code, "r")

      assert( message.has_position?)

      assert_in_delta(  12.576, message.latitude, 0.01)
      assert_in_delta( -12.576, message.longitude, 0.01)

      assert( message.has_comment?)
      assert_equal( message.comment, "AAAAAAAAAABBBBBBBBBB88888888")

      return
    end


    def test_compressed
      message = APRSMessage.new( "DL8RCB-3", "APU25N", [], "=/5m+5Qr4<# Bdoc u16 {UIV32N}")

      assert( message.has_symbol?)
      assert( ! message.has_position?)

      assert_equal( message.symbol_table, "/")
      assert_equal( message.symbol_code, "#")

      return
    end
    
  end

end

==> aprs4r-1.0.3.99.rc5.tar.gz: aprs4r-1.0.3.99.rc5/src/aprs4r/tests/APRSMessageTest.rb <==
#!/usr/bin/ruby
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@aprs4r.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'test/unit'

log4r_file = ENV['APRS4R_LOG4R'] || "#{default_path}/log4r.yaml"
print "log4r_file: #{log4r_file}\n"

require 'aprs4r/APRS4RLogger'
APRS4R::APRS4RLogger::load_yaml_file( log4r_file)

require 'aprs4r/APRSMessage'


module APRS4R

  class APRSMessageTest < Test::Unit::TestCase

    def test_latitude2decimal
      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00N"))
      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00S"))
    end

    def test_longitude2decimal
      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00E"))
      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00W"))
    end

    def test_degree2decimal_zero
      position1 = "0000.00N"
      assert_equal( 0.0, APRSMessage.degree2decimal( position1))

      position2 = "0000.00S"
      assert_equal( 0.0, APRSMessage.degree2decimal( position2))

      position3 = "00000.00E"
      assert_equal( 0.0, APRSMessage.degree2decimal( position3))

      position4 = "00000.00W"
      assert_equal( 0.0, APRSMessage.degree2decimal( position4))
    end

    
    def test_degree2decimal_north
      position = "4900.00N"
      assert_in_delta( 49.0, APRSMessage.degree2decimal( position), 0.0001)
      assert_not_equal( -49.0, APRSMessage.degree2decimal( position))
    end

    def test_degree2decimal_south
      position = "4930.00S"
      assert_in_delta( -49.50, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_second1
      position = "4930.50N"
      assert_in_delta( 49.5083, APRSMessage.degree2decimal( position), 0.0001)
    end

    
    def test_degree2decimal_east
      position = "00800.00E"
      assert_in_delta( 8.0, APRSMessage.degree2decimal( position), 0.0001)
      assert_not_equal( -8.0, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_west
      position = "11245.00W"
      assert_in_delta( -112.75, APRSMessage.degree2decimal( position), 0.0001)
    end

    def test_degree2decimal_second2
      position = "9423.69N"
      assert_in_delta( 94.3948, APRSMessage.degree2decimal( position), 0.0001)
    end


    def test_has_path
      no_path = APRSMessage.new( "FROM", "TO", nil, "")
      empty_path = APRSMessage.new( "FROM", "TO", [], "")

      assert( !no_path.has_path?)
      assert( !empty_path.has_path?)


      simple_path = APRSMessage.new( "FROM", "TO", ["CALL1"], "")
      complex_path = APRSMessage.new( "FROM", "TO", ["CALL1-3*", "WIDE2-1"], "")
      
      assert( simple_path.has_path?)
      assert( complex_path.has_path?)

      return
    end


    def test_is_local
      no_path = APRSMessage.new( "FROM", "TO", nil, "")
      empty_path = APRSMessage.new( "FROM", "TO", [], "")

      assert( no_path.is_local?)
      assert( empty_path.is_local?)

      
      local_path = APRSMessage.new( "FROM", "TO", ["WIDE1-1", "WIDE2-1"], "")
      remote_path = APRSMessage.new( "FROM", "TO", ["ABCDEF*", "WIDE1", "WIDE2-1"], "")

      assert( local_path.is_local?)
      assert( !remote_path.is_local?)

      return
    end

    
    def test_message
      message = APRSMessage.new( "FROM", "TO", [], ":ABCDEFGHI:Message")
      no_message = APRSMessage.new( "FROM", "TO", [], ">Statustext")

      assert( message.is_message?)
      assert( !no_message.is_message?)

      assert_equal( message.message_recipient, "ABCDEFGHI")
    end


    def test_message_ack
      ack = APRSMessage.new( "FROM", "TO", [], ":ABCDEFGHI:Message{12345")
      no_ack = APRSMessage.new( "FROM", "TO", [], ":ABCDEFGHI:Message")

      assert( ack.is_message?)
      assert( no_ack.is_message?)

      assert_equal( ack.message_ack, "12345")
      assert( no_ack.message_ack.nil?)
    end


    def test_object
      message = APRSMessage.new( "FROM", "TO", [], ";FFF.FFF+x*111111z1234.56N/01234.56WrAAAAAAAAAABBBBBBBBBB88888888")
      
      assert( message.is_object?)
      assert_equal( "FFF.FFF+x", message.object_address)
      
      assert( message.has_symbol?)
      assert_equal( message.symbol_table, "/")
      assert_equal( message.symbol_code, "r")

      assert( message.has_position?)

      assert_in_delta(  12.576, message.latitude, 0.01)
      assert_in_delta( -12.576, message.longitude, 0.01)

      assert( message.has_comment?)
      assert_equal( message.comment, "AAAAAAAAAABBBBBBBBBB88888888")

      return
    end

    
    def test_item

      message1 = APRSMessage.new( "FROM", "TO", [], ")ABC_XYZ")

      assert( message1.is_item?)
      assert_equal( "ABC", message1.item_address)


      message2 = APRSMessage.new( "FROM", "TO", [], ")ABC!XYZ")

      assert( message2.is_item?)
      assert_equal( "ABC", message2.item_address)


      message3 = APRSMessage.new( "FROM", "TO", [], ")ABCDEFGHI_XYZ")

      assert( message3.is_item?)
      assert_equal( "ABCDEFGHI", message3.item_address)


      message4 = APRSMessage.new( "FROM", "TO", [], ")ABCDEFGHI!XYZ")

      assert( message4.is_item?)
      assert_equal( "ABCDEFGHI", message4.item_address)

      return
    end
      


    def test_compressed
      message = APRSMessage.new( "DL8RCB-3", "APU25N", [], "=/5m+5Qr4<# Bdoc u16 {UIV32N}")

      assert( message.has_symbol?)
      assert( ! message.has_position?)

      assert_equal( message.symbol_table, "/")
      assert_equal( message.symbol_code, "#")

      return
    end


    def test_distance
      message = APRSMessage.new( "FROM", "TO", [], "!4900.00NI00825.00E&XML-Test")

      # print "latitude: #{message.latitude}, longitude: #{message.longitude}"
      # print "distance: #{message.distance( message.latitude, message.longitude)}"
      return
    end


    def test_query_payload
      message1 = APRSMessage.new( "FROM", "TO", [], ":ABCD     :?APRSH EFGH")

      assert( !message1.is_query?)
      assert( message1.is_message?)
      assert_equal( message1.query_payload, "EFGH")

      message2 = APRSMessage.new( "FROM", "TO", [], ":ABCD     :?APRSH EFGH-5")

      assert( !message2.is_query?)
      assert( message2.is_message?)
      assert_equal( message2.query_payload, "EFGH-5")
    end

  end

end
